Learn R Programming

extRemes (version 1.50)

gen.gev: Simulate data from a generalized extreme value (GEV)

Description

Generates data from a GEV (GPD) using 'runif' (and 'rexp') function. May also incorporate a linear trend in location parameter of GEV.

Usage

gen.gev(p, n, trend = NULL)
gen.gpd(n,sigma,xi,u)

Arguments

p
A $13$ vector indicating the mean, scale and shape of the GEV, respectively. n{ The sample size to generate.} trend{ Slope of the location parameter trend (if desired). } sigma{ Scale parameter