Learn R Programming

extRemes (version 1.50)

return.level: Computes m-year return levels for GEV and GPD with confidence bounds.

Description

Computes confidence limits for m-year return levels for GEV and GPD using profile likelihoods and a cubic spline ('splinefun'). It also computes the confidence levels using the ``delta" method.

Usage

return.level(z, conf = 0.05, rlevels= c(10,100,210,510,810,980), make.plot = TRUE)

Arguments

z
An object of class "gev.fit" or "gpd.fit" from the gev.fit or gpd.fit functions from the ismev library of Stuart Coles (ported to R by Alec Stephenson).
conf
The confidence level for confidence bounds.
rlevels
Return levels at which to compute confidence limits with profile likelihood plots--the rest will be interpolated with a spline function using the R function splinefun
make.plot
logical, if 'TRUE' plots the return levels with confidence bounds.

Value

  • Creates a plot if 'make.plot' is TRUE and returns a list invisibly with components.
  • return.levelThe m-year return levels.
  • return.periodThe return periods, m.
  • confidenceThe confidence bounds estimated from the profile likelihood.
  • confidence.deltaThe confidence bounds computed by the delta method.
  • conf.levelThe confidence level.

Details

This function is in part a modification of the functions 'gev.rl' and 'gpd.rl' from the ismev library. It allows for the plotted values to be returned (invisibly) as well as other confidence levels besides 97.5%.

Confidence levels are computed using both the profile likelihood method (for return levels given by 'rlevels') with a cubic spline (to interpolate for many values not given by 'rlevels') and by the delta method described in Coles (2001).

References

Coles, Stuart. "An Introduction to Statistical Modeling of Extreme Values", Springer 2001. ISBN: 1852334592

Gilleland, Eric, Katz, Richard W. and Young, Greg. Tutorial for the 'Extremes Toolkit: Weather and Climate Applications of Extreme Value Statistics.' http://www.assessment.ucar.edu/toolkit, 2005.

See Also

From the ismev package: gev.fit, gpd.fit, gev.diag, gpd.diag, gev.rl, gpd.rl

Examples

Run this code
# Must have the 'ismev' package loaded.
require( ismev)
data( ftcanmax)
fit <- gev.fit( ftcanmax[,"Prec"])
class( fit) <- "gev.fit" # 'gev.fit' does not actually assign this class,
			 # but it must be done.
return.level( fit)

Run the code above in your browser using DataLab