fpp(xdat, threshold, npy = 365, ydat = NULL, mul = NULL, sigl = NULL, shl = NULL, mulink = identity, siglink = identity, shlink = identity, show = TRUE, method = "Nelder-Mead", maxit = 10000, ...)This function is a modification of the pp.fit,
but uses the estimation $
trans: A logical indicator for a non-stationary fit.
model: A list with components 'mul', 'sigl' and 'shl'.
link: A character vector giving inverse link functions.
threshold: The threshold, or vector of thresholds.
npy: The number of observations per year/block.
nexc: The number of data points above the threshold.
data: The data that lie above the threshold. For non-stationary models, the data is standardized.
conv: The convergence code, taken from the list returned by 'optim'. A zero indicates successful convergence.
nllh: The negative logarithm of the likelihood evaluated at the maximum likelihood estimates.
vals: A matrix with four columns containing the maximum likelihood estimates of the location, scale and shape parameters, and the threshold, at each data point. model: A list with components 'mul', 'sigl' and 'shl'.
link: A character vector giving inverse link functions.
threshold: The threshold, or vector of thresholds.
npy: The number of observations per year/block.
nexc: The number of data points above the threshold.
data: The data that lie above the threshold. For non-stationary models, the data is standardized.
conv: The convergence code, taken from the list returned by 'optim'. A zero indicates successful convergence.
nllh: The negative logarithm of the likelihood evaluated at the maximum likelihood estimates.
vals: A matrix with four columns containing the maximum likelihood estimates of the location, scale and shape parameters, and the threshold, at each data point.
gpd: A matrix with three rows containing the maximum likelihood estimates of corresponding GPD location, scale and shape parameters at each data point.
mle: A vector containing the maximum likelihood estimates.
cov: The covariance matrix.
se: A vector containing the standard errors.
Coles, Stuart (2001). An Introduction to Statistical Modeling of
Extreme Values. Springer-Verlag, London.
[object Object],[object Object]
pp.fit, pp.diag, optim, pp.fitrange, mrl.plot, gpd.fit
# Perform a simple point process model fit. x <- FtCoPrec[,"Prec"] fit <- fpp( x, 0.395) pp.diag( fit)
# Add seasonal covariates.
Time <- FtCoPrec[,"obs"]
angle <- (2*pi*Time)/365.25
s <- cbind( sin( angle), cos( angle))
fit <- fpp( xdat=x, threshold=0.395, npy=365.25, ydat=s, mul=1:2, sigl=1:2, siglink=exp)
pp.diag( fit)